# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVolumeResult',
    'AwaitableGetVolumeResult',
    'get_volume',
    'get_volume_output',
]

@pulumi.output_type
class GetVolumeResult:
    """
    A collection of values returned by getVolume.
    """
    def __init__(__self__, auto_snapshot_policy_id=None, auto_snapshot_policy_name=None, baseline_performance=None, created_at=None, delete_with_instance=None, description=None, device_name=None, error_detail=None, expired_time=None, extra_performance=None, id=None, image_id=None, instance_id=None, kind=None, overdue_reclaim_time=None, overdue_time=None, pay_type=None, project_name=None, renew_type=None, size=None, snapshot_count=None, source_snapshot_id=None, status=None, tags=None, total_performance=None, trade_status=None, updated_at=None, volume_id=None, volume_name=None, volume_type=None, zone_id=None):
        if auto_snapshot_policy_id and not isinstance(auto_snapshot_policy_id, str):
            raise TypeError("Expected argument 'auto_snapshot_policy_id' to be a str")
        pulumi.set(__self__, "auto_snapshot_policy_id", auto_snapshot_policy_id)
        if auto_snapshot_policy_name and not isinstance(auto_snapshot_policy_name, str):
            raise TypeError("Expected argument 'auto_snapshot_policy_name' to be a str")
        pulumi.set(__self__, "auto_snapshot_policy_name", auto_snapshot_policy_name)
        if baseline_performance and not isinstance(baseline_performance, dict):
            raise TypeError("Expected argument 'baseline_performance' to be a dict")
        pulumi.set(__self__, "baseline_performance", baseline_performance)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if delete_with_instance and not isinstance(delete_with_instance, bool):
            raise TypeError("Expected argument 'delete_with_instance' to be a bool")
        pulumi.set(__self__, "delete_with_instance", delete_with_instance)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if device_name and not isinstance(device_name, str):
            raise TypeError("Expected argument 'device_name' to be a str")
        pulumi.set(__self__, "device_name", device_name)
        if error_detail and not isinstance(error_detail, str):
            raise TypeError("Expected argument 'error_detail' to be a str")
        pulumi.set(__self__, "error_detail", error_detail)
        if expired_time and not isinstance(expired_time, str):
            raise TypeError("Expected argument 'expired_time' to be a str")
        pulumi.set(__self__, "expired_time", expired_time)
        if extra_performance and not isinstance(extra_performance, dict):
            raise TypeError("Expected argument 'extra_performance' to be a dict")
        pulumi.set(__self__, "extra_performance", extra_performance)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if overdue_reclaim_time and not isinstance(overdue_reclaim_time, str):
            raise TypeError("Expected argument 'overdue_reclaim_time' to be a str")
        pulumi.set(__self__, "overdue_reclaim_time", overdue_reclaim_time)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if pay_type and not isinstance(pay_type, str):
            raise TypeError("Expected argument 'pay_type' to be a str")
        pulumi.set(__self__, "pay_type", pay_type)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if renew_type and not isinstance(renew_type, float):
            raise TypeError("Expected argument 'renew_type' to be a float")
        pulumi.set(__self__, "renew_type", renew_type)
        if size and not isinstance(size, float):
            raise TypeError("Expected argument 'size' to be a float")
        pulumi.set(__self__, "size", size)
        if snapshot_count and not isinstance(snapshot_count, float):
            raise TypeError("Expected argument 'snapshot_count' to be a float")
        pulumi.set(__self__, "snapshot_count", snapshot_count)
        if source_snapshot_id and not isinstance(source_snapshot_id, str):
            raise TypeError("Expected argument 'source_snapshot_id' to be a str")
        pulumi.set(__self__, "source_snapshot_id", source_snapshot_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if total_performance and not isinstance(total_performance, dict):
            raise TypeError("Expected argument 'total_performance' to be a dict")
        pulumi.set(__self__, "total_performance", total_performance)
        if trade_status and not isinstance(trade_status, float):
            raise TypeError("Expected argument 'trade_status' to be a float")
        pulumi.set(__self__, "trade_status", trade_status)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if volume_id and not isinstance(volume_id, str):
            raise TypeError("Expected argument 'volume_id' to be a str")
        pulumi.set(__self__, "volume_id", volume_id)
        if volume_name and not isinstance(volume_name, str):
            raise TypeError("Expected argument 'volume_name' to be a str")
        pulumi.set(__self__, "volume_name", volume_name)
        if volume_type and not isinstance(volume_type, str):
            raise TypeError("Expected argument 'volume_type' to be a str")
        pulumi.set(__self__, "volume_type", volume_type)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="autoSnapshotPolicyId")
    def auto_snapshot_policy_id(self) -> builtins.str:
        """
        自动快照策略ID。
        """
        return pulumi.get(self, "auto_snapshot_policy_id")

    @property
    @pulumi.getter(name="autoSnapshotPolicyName")
    def auto_snapshot_policy_name(self) -> builtins.str:
        """
        自动快照策略名称。
        """
        return pulumi.get(self, "auto_snapshot_policy_name")

    @property
    @pulumi.getter(name="baselinePerformance")
    def baseline_performance(self) -> 'outputs.GetVolumeBaselinePerformanceResult':
        """
        基本性能。
        """
        return pulumi.get(self, "baseline_performance")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        云盘创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="deleteWithInstance")
    def delete_with_instance(self) -> builtins.bool:
        """
        释放实例时，该云盘是否随实例一起释放，取值说明如下：true：云盘随实例一起释放。false：云盘不随实例一起释放。
        """
        return pulumi.get(self, "delete_with_instance")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        云盘的描述信息，默认为空，长度限制在1 ~ 255字符之间。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="deviceName")
    def device_name(self) -> builtins.str:
        """
        设备名称
        """
        return pulumi.get(self, "device_name")

    @property
    @pulumi.getter(name="errorDetail")
    def error_detail(self) -> builtins.str:
        """
        具体错误
        """
        return pulumi.get(self, "error_detail")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> builtins.str:
        """
        包年包月到期时间。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="extraPerformance")
    def extra_performance(self) -> 'outputs.GetVolumeExtraPerformanceResult':
        """
        额外性能。
        """
        return pulumi.get(self, "extra_performance")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        云盘中的镜像ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        创建云盘的同时挂载的ECS实例ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def kind(self) -> builtins.str:
        """
        云盘属性，data表示数据盘。默认值为data。说明： 仅支持创建数据盘。
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter(name="overdueReclaimTime")
    def overdue_reclaim_time(self) -> builtins.str:
        """
        云盘欠费回收时间。
        """
        return pulumi.get(self, "overdue_reclaim_time")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        云盘欠费关停时间。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="payType")
    def pay_type(self) -> builtins.str:
        """
        付费类型，说明如下： Pre：预付费（包年包月） Post：后付费（按量计费）。
        """
        return pulumi.get(self, "pay_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        云盘所要加入的Project（项目）名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="renewType")
    def renew_type(self) -> builtins.float:
        """
        续费方式 1：手动续费 2 ：自动续费 3 ：到期不续费。
        """
        return pulumi.get(self, "renew_type")

    @property
    @pulumi.getter
    def size(self) -> builtins.float:
        """
        Size，数据盘容量大小，单位为GiB。不同类型的数据盘容量范围如下：ESSD*PL0：10~65536 GiB；ESSD*FlexPL：10~65536 GiB；TSSD_TL0：40~65536 GiB
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotCount")
    def snapshot_count(self) -> builtins.float:
        """
        快照计数
        """
        return pulumi.get(self, "snapshot_count")

    @property
    @pulumi.getter(name="sourceSnapshotId")
    def source_snapshot_id(self) -> builtins.str:
        """
        源快照。
        """
        return pulumi.get(self, "source_snapshot_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        云盘状态，取值说明如下：available：可用。attaching：挂载中。attached：已挂载。detaching：卸载中。creating：创建中。deleting：删除中。error：错误。extending：扩容中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetVolumeTagResult']:
        """
        云盘的标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="totalPerformance")
    def total_performance(self) -> 'outputs.GetVolumeTotalPerformanceResult':
        """
        总性能。
        """
        return pulumi.get(self, "total_performance")

    @property
    @pulumi.getter(name="tradeStatus")
    def trade_status(self) -> builtins.float:
        """
        交易状态 0：创建中 1：运行中 2：创建失败
        """
        return pulumi.get(self, "trade_status")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        云盘更新时间。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> builtins.str:
        """
        云盘id。
        """
        return pulumi.get(self, "volume_id")

    @property
    @pulumi.getter(name="volumeName")
    def volume_name(self) -> builtins.str:
        """
        云盘显示名称。命名规则如下：首字符仅支持中文、字母或下划线（*）。可包含中文、字母、数字、下划线（*）或中划线（-）。长度限制在1~128字符之间。
        """
        return pulumi.get(self, "volume_name")

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> builtins.str:
        """
        云盘类型，取值说明如下：ESSD*PL0：极速型SSD云盘，PL0规格。ESSD*FlexPL: 极速型SSD云盘，FlexPL规格。TSSD_TL0: 吞吐型SSD云盘。
        """
        return pulumi.get(self, "volume_type")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        可用区ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetVolumeResult(GetVolumeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVolumeResult(
            auto_snapshot_policy_id=self.auto_snapshot_policy_id,
            auto_snapshot_policy_name=self.auto_snapshot_policy_name,
            baseline_performance=self.baseline_performance,
            created_at=self.created_at,
            delete_with_instance=self.delete_with_instance,
            description=self.description,
            device_name=self.device_name,
            error_detail=self.error_detail,
            expired_time=self.expired_time,
            extra_performance=self.extra_performance,
            id=self.id,
            image_id=self.image_id,
            instance_id=self.instance_id,
            kind=self.kind,
            overdue_reclaim_time=self.overdue_reclaim_time,
            overdue_time=self.overdue_time,
            pay_type=self.pay_type,
            project_name=self.project_name,
            renew_type=self.renew_type,
            size=self.size,
            snapshot_count=self.snapshot_count,
            source_snapshot_id=self.source_snapshot_id,
            status=self.status,
            tags=self.tags,
            total_performance=self.total_performance,
            trade_status=self.trade_status,
            updated_at=self.updated_at,
            volume_id=self.volume_id,
            volume_name=self.volume_name,
            volume_type=self.volume_type,
            zone_id=self.zone_id)


def get_volume(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVolumeResult:
    """
    Data Source schema for Byteplus::StorageEBS::Volume


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:storageebs/getVolume:getVolume', __args__, opts=opts, typ=GetVolumeResult).value

    return AwaitableGetVolumeResult(
        auto_snapshot_policy_id=pulumi.get(__ret__, 'auto_snapshot_policy_id'),
        auto_snapshot_policy_name=pulumi.get(__ret__, 'auto_snapshot_policy_name'),
        baseline_performance=pulumi.get(__ret__, 'baseline_performance'),
        created_at=pulumi.get(__ret__, 'created_at'),
        delete_with_instance=pulumi.get(__ret__, 'delete_with_instance'),
        description=pulumi.get(__ret__, 'description'),
        device_name=pulumi.get(__ret__, 'device_name'),
        error_detail=pulumi.get(__ret__, 'error_detail'),
        expired_time=pulumi.get(__ret__, 'expired_time'),
        extra_performance=pulumi.get(__ret__, 'extra_performance'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        kind=pulumi.get(__ret__, 'kind'),
        overdue_reclaim_time=pulumi.get(__ret__, 'overdue_reclaim_time'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        pay_type=pulumi.get(__ret__, 'pay_type'),
        project_name=pulumi.get(__ret__, 'project_name'),
        renew_type=pulumi.get(__ret__, 'renew_type'),
        size=pulumi.get(__ret__, 'size'),
        snapshot_count=pulumi.get(__ret__, 'snapshot_count'),
        source_snapshot_id=pulumi.get(__ret__, 'source_snapshot_id'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        total_performance=pulumi.get(__ret__, 'total_performance'),
        trade_status=pulumi.get(__ret__, 'trade_status'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        volume_id=pulumi.get(__ret__, 'volume_id'),
        volume_name=pulumi.get(__ret__, 'volume_name'),
        volume_type=pulumi.get(__ret__, 'volume_type'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_volume_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVolumeResult]:
    """
    Data Source schema for Byteplus::StorageEBS::Volume


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:storageebs/getVolume:getVolume', __args__, opts=opts, typ=GetVolumeResult)
    return __ret__.apply(lambda __response__: GetVolumeResult(
        auto_snapshot_policy_id=pulumi.get(__response__, 'auto_snapshot_policy_id'),
        auto_snapshot_policy_name=pulumi.get(__response__, 'auto_snapshot_policy_name'),
        baseline_performance=pulumi.get(__response__, 'baseline_performance'),
        created_at=pulumi.get(__response__, 'created_at'),
        delete_with_instance=pulumi.get(__response__, 'delete_with_instance'),
        description=pulumi.get(__response__, 'description'),
        device_name=pulumi.get(__response__, 'device_name'),
        error_detail=pulumi.get(__response__, 'error_detail'),
        expired_time=pulumi.get(__response__, 'expired_time'),
        extra_performance=pulumi.get(__response__, 'extra_performance'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        kind=pulumi.get(__response__, 'kind'),
        overdue_reclaim_time=pulumi.get(__response__, 'overdue_reclaim_time'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        pay_type=pulumi.get(__response__, 'pay_type'),
        project_name=pulumi.get(__response__, 'project_name'),
        renew_type=pulumi.get(__response__, 'renew_type'),
        size=pulumi.get(__response__, 'size'),
        snapshot_count=pulumi.get(__response__, 'snapshot_count'),
        source_snapshot_id=pulumi.get(__response__, 'source_snapshot_id'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        total_performance=pulumi.get(__response__, 'total_performance'),
        trade_status=pulumi.get(__response__, 'trade_status'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        volume_id=pulumi.get(__response__, 'volume_id'),
        volume_name=pulumi.get(__response__, 'volume_name'),
        volume_type=pulumi.get(__response__, 'volume_type'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SandboxArgs', 'Sandbox']

@pulumi.input_type
class SandboxArgs:
    def __init__(__self__, *,
                 function_id: pulumi.Input[builtins.str],
                 cpu_milli: Optional[pulumi.Input[builtins.int]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxEnvArgs']]]] = None,
                 instance_image_info: Optional[pulumi.Input['SandboxInstanceImageInfoArgs']] = None,
                 instance_tos_mount_config: Optional[pulumi.Input['SandboxInstanceTosMountConfigArgs']] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.int]] = None,
                 memory_mb: Optional[pulumi.Input[builtins.int]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxMetadataArgs']]]] = None,
                 request_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a Sandbox resource.
        :param pulumi.Input[builtins.str] function_id: 沙箱实例所属的沙箱应用 ID。
        :param pulumi.Input[builtins.int] cpu_milli: 沙箱实例 CPU 规格：单位：milli cpu取值范围：250~16000,默认值：1000。
        :param pulumi.Input['SandboxInstanceImageInfoArgs'] instance_image_info: 沙箱实例镜像信息，包括镜像地址、启动命令、监听端口。
        :param pulumi.Input['SandboxInstanceTosMountConfigArgs'] instance_tos_mount_config: 沙箱实例级别对象存储（TOS）存储挂载配置。
        :param pulumi.Input[builtins.int] max_concurrency: 单实例请求最大并发数：取值范围：10~1000,默认值：100。
        :param pulumi.Input[builtins.int] memory_mb: 沙箱实例内存规格：单位：MiB，取值范围：512~131072，默认值：2048
        :param pulumi.Input[builtins.int] request_timeout: 请求超时时间：单位：秒，取值范围：1~900，正整数。默认值：30。
        :param pulumi.Input[builtins.int] timeout: 沙箱实例存活时长：单位：分钟，取值范围：3～1440，默认值：60。
        """
        pulumi.set(__self__, "function_id", function_id)
        if cpu_milli is not None:
            pulumi.set(__self__, "cpu_milli", cpu_milli)
        if envs is not None:
            pulumi.set(__self__, "envs", envs)
        if instance_image_info is not None:
            pulumi.set(__self__, "instance_image_info", instance_image_info)
        if instance_tos_mount_config is not None:
            pulumi.set(__self__, "instance_tos_mount_config", instance_tos_mount_config)
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if memory_mb is not None:
            pulumi.set(__self__, "memory_mb", memory_mb)
        if metadatas is not None:
            pulumi.set(__self__, "metadatas", metadatas)
        if request_timeout is not None:
            pulumi.set(__self__, "request_timeout", request_timeout)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> pulumi.Input[builtins.str]:
        """
        沙箱实例所属的沙箱应用 ID。
        """
        return pulumi.get(self, "function_id")

    @function_id.setter
    def function_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "function_id", value)

    @property
    @pulumi.getter(name="cpuMilli")
    def cpu_milli(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        沙箱实例 CPU 规格：单位：milli cpu取值范围：250~16000,默认值：1000。
        """
        return pulumi.get(self, "cpu_milli")

    @cpu_milli.setter
    def cpu_milli(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cpu_milli", value)

    @property
    @pulumi.getter
    def envs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SandboxEnvArgs']]]]:
        return pulumi.get(self, "envs")

    @envs.setter
    def envs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxEnvArgs']]]]):
        pulumi.set(self, "envs", value)

    @property
    @pulumi.getter(name="instanceImageInfo")
    def instance_image_info(self) -> Optional[pulumi.Input['SandboxInstanceImageInfoArgs']]:
        """
        沙箱实例镜像信息，包括镜像地址、启动命令、监听端口。
        """
        return pulumi.get(self, "instance_image_info")

    @instance_image_info.setter
    def instance_image_info(self, value: Optional[pulumi.Input['SandboxInstanceImageInfoArgs']]):
        pulumi.set(self, "instance_image_info", value)

    @property
    @pulumi.getter(name="instanceTosMountConfig")
    def instance_tos_mount_config(self) -> Optional[pulumi.Input['SandboxInstanceTosMountConfigArgs']]:
        """
        沙箱实例级别对象存储（TOS）存储挂载配置。
        """
        return pulumi.get(self, "instance_tos_mount_config")

    @instance_tos_mount_config.setter
    def instance_tos_mount_config(self, value: Optional[pulumi.Input['SandboxInstanceTosMountConfigArgs']]):
        pulumi.set(self, "instance_tos_mount_config", value)

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        单实例请求最大并发数：取值范围：10~1000,默认值：100。
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_concurrency", value)

    @property
    @pulumi.getter(name="memoryMb")
    def memory_mb(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        沙箱实例内存规格：单位：MiB，取值范围：512~131072，默认值：2048
        """
        return pulumi.get(self, "memory_mb")

    @memory_mb.setter
    def memory_mb(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "memory_mb", value)

    @property
    @pulumi.getter
    def metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SandboxMetadataArgs']]]]:
        return pulumi.get(self, "metadatas")

    @metadatas.setter
    def metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxMetadataArgs']]]]):
        pulumi.set(self, "metadatas", value)

    @property
    @pulumi.getter(name="requestTimeout")
    def request_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        请求超时时间：单位：秒，取值范围：1~900，正整数。默认值：30。
        """
        return pulumi.get(self, "request_timeout")

    @request_timeout.setter
    def request_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "request_timeout", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        沙箱实例存活时长：单位：分钟，取值范围：3～1440，默认值：60。
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class _SandboxState:
    def __init__(__self__, *,
                 availability_zone: Optional[pulumi.Input[builtins.str]] = None,
                 cpu_milli: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxEnvArgs']]]] = None,
                 error_code: Optional[pulumi.Input[builtins.str]] = None,
                 error_message: Optional[pulumi.Input[builtins.str]] = None,
                 expire_at: Optional[pulumi.Input[builtins.str]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_image_info: Optional[pulumi.Input['SandboxInstanceImageInfoArgs']] = None,
                 instance_tos_mount_config: Optional[pulumi.Input['SandboxInstanceTosMountConfigArgs']] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.int]] = None,
                 memory_mb: Optional[pulumi.Input[builtins.int]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxMetadataArgs']]]] = None,
                 pending: Optional[pulumi.Input[builtins.bool]] = None,
                 request_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 revision_number: Optional[pulumi.Input[builtins.int]] = None,
                 sandbox_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering Sandbox resources.
        :param pulumi.Input[builtins.str] availability_zone: 沙箱实例所在可用区 ID。
        :param pulumi.Input[builtins.int] cpu_milli: 沙箱实例 CPU 规格：单位：milli cpu取值范围：250~16000,默认值：1000。
        :param pulumi.Input[builtins.str] created_time: 沙箱实例创建时间。
        :param pulumi.Input[builtins.str] error_code: 沙箱实例启动失败错误码。参数值说明：internal*load*request*error：系统内部错误，function*initialize*failed：业务进程初始化错误，function*health*check*failed：健康检查错误，route_terminating：路由删除中，正常启动沙箱实例时，该字段为空。
        :param pulumi.Input[builtins.str] error_message: 沙箱实例启动失败的错误码详情。正常启动沙箱实例时，该字段为空。
        :param pulumi.Input[builtins.str] expire_at: 沙箱实例存活时长。
        :param pulumi.Input[builtins.str] function_id: 沙箱实例所属的沙箱应用 ID。
        :param pulumi.Input['SandboxInstanceImageInfoArgs'] instance_image_info: 沙箱实例镜像信息，包括镜像地址、启动命令、监听端口。
        :param pulumi.Input['SandboxInstanceTosMountConfigArgs'] instance_tos_mount_config: 沙箱实例级别对象存储（TOS）存储挂载配置。
        :param pulumi.Input[builtins.str] instance_type: 沙箱实例类型 。参数值说明：elastic：弹性实例，frozen：冻结实例，activated：激活实例，reserved：预留实例。
        :param pulumi.Input[builtins.int] max_concurrency: 单实例请求最大并发数：取值范围：10~1000,默认值：100。
        :param pulumi.Input[builtins.int] memory_mb: 沙箱实例内存规格：单位：MiB，取值范围：512~131072，默认值：2048
        :param pulumi.Input[builtins.bool] pending: 沙箱实例是否处于 Pending 状态。参数值说明：true：是，false：否。
        :param pulumi.Input[builtins.int] request_timeout: 请求超时时间：单位：秒，取值范围：1~900，正整数。默认值：30。
        :param pulumi.Input[builtins.int] revision_number: 函数实例版本编号。
        :param pulumi.Input[builtins.str] sandbox_id: 沙箱实例 ID。
        :param pulumi.Input[builtins.str] status: 沙箱实例状态。 参数值说明：Starting：开始启动，Ready：启动完成，Failed：启动失败，Terminating：终止中。
        :param pulumi.Input[builtins.int] timeout: 沙箱实例存活时长：单位：分钟，取值范围：3～1440，默认值：60。
        """
        if availability_zone is not None:
            pulumi.set(__self__, "availability_zone", availability_zone)
        if cpu_milli is not None:
            pulumi.set(__self__, "cpu_milli", cpu_milli)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if envs is not None:
            pulumi.set(__self__, "envs", envs)
        if error_code is not None:
            pulumi.set(__self__, "error_code", error_code)
        if error_message is not None:
            pulumi.set(__self__, "error_message", error_message)
        if expire_at is not None:
            pulumi.set(__self__, "expire_at", expire_at)
        if function_id is not None:
            pulumi.set(__self__, "function_id", function_id)
        if instance_image_info is not None:
            pulumi.set(__self__, "instance_image_info", instance_image_info)
        if instance_tos_mount_config is not None:
            pulumi.set(__self__, "instance_tos_mount_config", instance_tos_mount_config)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if memory_mb is not None:
            pulumi.set(__self__, "memory_mb", memory_mb)
        if metadatas is not None:
            pulumi.set(__self__, "metadatas", metadatas)
        if pending is not None:
            pulumi.set(__self__, "pending", pending)
        if request_timeout is not None:
            pulumi.set(__self__, "request_timeout", request_timeout)
        if revision_number is not None:
            pulumi.set(__self__, "revision_number", revision_number)
        if sandbox_id is not None:
            pulumi.set(__self__, "sandbox_id", sandbox_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例所在可用区 ID。
        """
        return pulumi.get(self, "availability_zone")

    @availability_zone.setter
    def availability_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "availability_zone", value)

    @property
    @pulumi.getter(name="cpuMilli")
    def cpu_milli(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        沙箱实例 CPU 规格：单位：milli cpu取值范围：250~16000,默认值：1000。
        """
        return pulumi.get(self, "cpu_milli")

    @cpu_milli.setter
    def cpu_milli(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cpu_milli", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def envs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SandboxEnvArgs']]]]:
        return pulumi.get(self, "envs")

    @envs.setter
    def envs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxEnvArgs']]]]):
        pulumi.set(self, "envs", value)

    @property
    @pulumi.getter(name="errorCode")
    def error_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例启动失败错误码。参数值说明：internal*load*request*error：系统内部错误，function*initialize*failed：业务进程初始化错误，function*health*check*failed：健康检查错误，route_terminating：路由删除中，正常启动沙箱实例时，该字段为空。
        """
        return pulumi.get(self, "error_code")

    @error_code.setter
    def error_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "error_code", value)

    @property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例启动失败的错误码详情。正常启动沙箱实例时，该字段为空。
        """
        return pulumi.get(self, "error_message")

    @error_message.setter
    def error_message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "error_message", value)

    @property
    @pulumi.getter(name="expireAt")
    def expire_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例存活时长。
        """
        return pulumi.get(self, "expire_at")

    @expire_at.setter
    def expire_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expire_at", value)

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例所属的沙箱应用 ID。
        """
        return pulumi.get(self, "function_id")

    @function_id.setter
    def function_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "function_id", value)

    @property
    @pulumi.getter(name="instanceImageInfo")
    def instance_image_info(self) -> Optional[pulumi.Input['SandboxInstanceImageInfoArgs']]:
        """
        沙箱实例镜像信息，包括镜像地址、启动命令、监听端口。
        """
        return pulumi.get(self, "instance_image_info")

    @instance_image_info.setter
    def instance_image_info(self, value: Optional[pulumi.Input['SandboxInstanceImageInfoArgs']]):
        pulumi.set(self, "instance_image_info", value)

    @property
    @pulumi.getter(name="instanceTosMountConfig")
    def instance_tos_mount_config(self) -> Optional[pulumi.Input['SandboxInstanceTosMountConfigArgs']]:
        """
        沙箱实例级别对象存储（TOS）存储挂载配置。
        """
        return pulumi.get(self, "instance_tos_mount_config")

    @instance_tos_mount_config.setter
    def instance_tos_mount_config(self, value: Optional[pulumi.Input['SandboxInstanceTosMountConfigArgs']]):
        pulumi.set(self, "instance_tos_mount_config", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例类型 。参数值说明：elastic：弹性实例，frozen：冻结实例，activated：激活实例，reserved：预留实例。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        单实例请求最大并发数：取值范围：10~1000,默认值：100。
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_concurrency", value)

    @property
    @pulumi.getter(name="memoryMb")
    def memory_mb(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        沙箱实例内存规格：单位：MiB，取值范围：512~131072，默认值：2048
        """
        return pulumi.get(self, "memory_mb")

    @memory_mb.setter
    def memory_mb(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "memory_mb", value)

    @property
    @pulumi.getter
    def metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SandboxMetadataArgs']]]]:
        return pulumi.get(self, "metadatas")

    @metadatas.setter
    def metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SandboxMetadataArgs']]]]):
        pulumi.set(self, "metadatas", value)

    @property
    @pulumi.getter
    def pending(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        沙箱实例是否处于 Pending 状态。参数值说明：true：是，false：否。
        """
        return pulumi.get(self, "pending")

    @pending.setter
    def pending(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pending", value)

    @property
    @pulumi.getter(name="requestTimeout")
    def request_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        请求超时时间：单位：秒，取值范围：1~900，正整数。默认值：30。
        """
        return pulumi.get(self, "request_timeout")

    @request_timeout.setter
    def request_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "request_timeout", value)

    @property
    @pulumi.getter(name="revisionNumber")
    def revision_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        函数实例版本编号。
        """
        return pulumi.get(self, "revision_number")

    @revision_number.setter
    def revision_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "revision_number", value)

    @property
    @pulumi.getter(name="sandboxId")
    def sandbox_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例 ID。
        """
        return pulumi.get(self, "sandbox_id")

    @sandbox_id.setter
    def sandbox_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sandbox_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        沙箱实例状态。 参数值说明：Starting：开始启动，Ready：启动完成，Failed：启动失败，Terminating：终止中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        沙箱实例存活时长：单位：分钟，取值范围：3～1440，默认值：60。
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.type_token("bytepluscc:vefaas/sandbox:Sandbox")
class Sandbox(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cpu_milli: Optional[pulumi.Input[builtins.int]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SandboxEnvArgs', 'SandboxEnvArgsDict']]]]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_image_info: Optional[pulumi.Input[Union['SandboxInstanceImageInfoArgs', 'SandboxInstanceImageInfoArgsDict']]] = None,
                 instance_tos_mount_config: Optional[pulumi.Input[Union['SandboxInstanceTosMountConfigArgs', 'SandboxInstanceTosMountConfigArgsDict']]] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.int]] = None,
                 memory_mb: Optional[pulumi.Input[builtins.int]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SandboxMetadataArgs', 'SandboxMetadataArgsDict']]]]] = None,
                 request_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        沙箱实例是云沙箱中实际执行沙箱镜像的安全且隔离的容器运行环境。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vefaas/sandbox:Sandbox example "function_id|sandbox_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] cpu_milli: 沙箱实例 CPU 规格：单位：milli cpu取值范围：250~16000,默认值：1000。
        :param pulumi.Input[builtins.str] function_id: 沙箱实例所属的沙箱应用 ID。
        :param pulumi.Input[Union['SandboxInstanceImageInfoArgs', 'SandboxInstanceImageInfoArgsDict']] instance_image_info: 沙箱实例镜像信息，包括镜像地址、启动命令、监听端口。
        :param pulumi.Input[Union['SandboxInstanceTosMountConfigArgs', 'SandboxInstanceTosMountConfigArgsDict']] instance_tos_mount_config: 沙箱实例级别对象存储（TOS）存储挂载配置。
        :param pulumi.Input[builtins.int] max_concurrency: 单实例请求最大并发数：取值范围：10~1000,默认值：100。
        :param pulumi.Input[builtins.int] memory_mb: 沙箱实例内存规格：单位：MiB，取值范围：512~131072，默认值：2048
        :param pulumi.Input[builtins.int] request_timeout: 请求超时时间：单位：秒，取值范围：1~900，正整数。默认值：30。
        :param pulumi.Input[builtins.int] timeout: 沙箱实例存活时长：单位：分钟，取值范围：3～1440，默认值：60。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SandboxArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        沙箱实例是云沙箱中实际执行沙箱镜像的安全且隔离的容器运行环境。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vefaas/sandbox:Sandbox example "function_id|sandbox_id"
        ```

        :param str resource_name: The name of the resource.
        :param SandboxArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SandboxArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cpu_milli: Optional[pulumi.Input[builtins.int]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SandboxEnvArgs', 'SandboxEnvArgsDict']]]]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_image_info: Optional[pulumi.Input[Union['SandboxInstanceImageInfoArgs', 'SandboxInstanceImageInfoArgsDict']]] = None,
                 instance_tos_mount_config: Optional[pulumi.Input[Union['SandboxInstanceTosMountConfigArgs', 'SandboxInstanceTosMountConfigArgsDict']]] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.int]] = None,
                 memory_mb: Optional[pulumi.Input[builtins.int]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SandboxMetadataArgs', 'SandboxMetadataArgsDict']]]]] = None,
                 request_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SandboxArgs.__new__(SandboxArgs)

            __props__.__dict__["cpu_milli"] = cpu_milli
            __props__.__dict__["envs"] = envs
            if function_id is None and not opts.urn:
                raise TypeError("Missing required property 'function_id'")
            __props__.__dict__["function_id"] = function_id
            __props__.__dict__["instance_image_info"] = instance_image_info
            __props__.__dict__["instance_tos_mount_config"] = instance_tos_mount_config
            __props__.__dict__["max_concurrency"] = max_concurrency
            __props__.__dict__["memory_mb"] = memory_mb
            __props__.__dict__["metadatas"] = metadatas
            __props__.__dict__["request_timeout"] = request_timeout
            __props__.__dict__["timeout"] = timeout
            __props__.__dict__["availability_zone"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["error_code"] = None
            __props__.__dict__["error_message"] = None
            __props__.__dict__["expire_at"] = None
            __props__.__dict__["instance_type"] = None
            __props__.__dict__["pending"] = None
            __props__.__dict__["revision_number"] = None
            __props__.__dict__["sandbox_id"] = None
            __props__.__dict__["status"] = None
        super(Sandbox, __self__).__init__(
            'bytepluscc:vefaas/sandbox:Sandbox',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            availability_zone: Optional[pulumi.Input[builtins.str]] = None,
            cpu_milli: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            envs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SandboxEnvArgs', 'SandboxEnvArgsDict']]]]] = None,
            error_code: Optional[pulumi.Input[builtins.str]] = None,
            error_message: Optional[pulumi.Input[builtins.str]] = None,
            expire_at: Optional[pulumi.Input[builtins.str]] = None,
            function_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_image_info: Optional[pulumi.Input[Union['SandboxInstanceImageInfoArgs', 'SandboxInstanceImageInfoArgsDict']]] = None,
            instance_tos_mount_config: Optional[pulumi.Input[Union['SandboxInstanceTosMountConfigArgs', 'SandboxInstanceTosMountConfigArgsDict']]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            max_concurrency: Optional[pulumi.Input[builtins.int]] = None,
            memory_mb: Optional[pulumi.Input[builtins.int]] = None,
            metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SandboxMetadataArgs', 'SandboxMetadataArgsDict']]]]] = None,
            pending: Optional[pulumi.Input[builtins.bool]] = None,
            request_timeout: Optional[pulumi.Input[builtins.int]] = None,
            revision_number: Optional[pulumi.Input[builtins.int]] = None,
            sandbox_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            timeout: Optional[pulumi.Input[builtins.int]] = None) -> 'Sandbox':
        """
        Get an existing Sandbox resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] availability_zone: 沙箱实例所在可用区 ID。
        :param pulumi.Input[builtins.int] cpu_milli: 沙箱实例 CPU 规格：单位：milli cpu取值范围：250~16000,默认值：1000。
        :param pulumi.Input[builtins.str] created_time: 沙箱实例创建时间。
        :param pulumi.Input[builtins.str] error_code: 沙箱实例启动失败错误码。参数值说明：internal*load*request*error：系统内部错误，function*initialize*failed：业务进程初始化错误，function*health*check*failed：健康检查错误，route_terminating：路由删除中，正常启动沙箱实例时，该字段为空。
        :param pulumi.Input[builtins.str] error_message: 沙箱实例启动失败的错误码详情。正常启动沙箱实例时，该字段为空。
        :param pulumi.Input[builtins.str] expire_at: 沙箱实例存活时长。
        :param pulumi.Input[builtins.str] function_id: 沙箱实例所属的沙箱应用 ID。
        :param pulumi.Input[Union['SandboxInstanceImageInfoArgs', 'SandboxInstanceImageInfoArgsDict']] instance_image_info: 沙箱实例镜像信息，包括镜像地址、启动命令、监听端口。
        :param pulumi.Input[Union['SandboxInstanceTosMountConfigArgs', 'SandboxInstanceTosMountConfigArgsDict']] instance_tos_mount_config: 沙箱实例级别对象存储（TOS）存储挂载配置。
        :param pulumi.Input[builtins.str] instance_type: 沙箱实例类型 。参数值说明：elastic：弹性实例，frozen：冻结实例，activated：激活实例，reserved：预留实例。
        :param pulumi.Input[builtins.int] max_concurrency: 单实例请求最大并发数：取值范围：10~1000,默认值：100。
        :param pulumi.Input[builtins.int] memory_mb: 沙箱实例内存规格：单位：MiB，取值范围：512~131072，默认值：2048
        :param pulumi.Input[builtins.bool] pending: 沙箱实例是否处于 Pending 状态。参数值说明：true：是，false：否。
        :param pulumi.Input[builtins.int] request_timeout: 请求超时时间：单位：秒，取值范围：1~900，正整数。默认值：30。
        :param pulumi.Input[builtins.int] revision_number: 函数实例版本编号。
        :param pulumi.Input[builtins.str] sandbox_id: 沙箱实例 ID。
        :param pulumi.Input[builtins.str] status: 沙箱实例状态。 参数值说明：Starting：开始启动，Ready：启动完成，Failed：启动失败，Terminating：终止中。
        :param pulumi.Input[builtins.int] timeout: 沙箱实例存活时长：单位：分钟，取值范围：3～1440，默认值：60。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SandboxState.__new__(_SandboxState)

        __props__.__dict__["availability_zone"] = availability_zone
        __props__.__dict__["cpu_milli"] = cpu_milli
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["envs"] = envs
        __props__.__dict__["error_code"] = error_code
        __props__.__dict__["error_message"] = error_message
        __props__.__dict__["expire_at"] = expire_at
        __props__.__dict__["function_id"] = function_id
        __props__.__dict__["instance_image_info"] = instance_image_info
        __props__.__dict__["instance_tos_mount_config"] = instance_tos_mount_config
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["max_concurrency"] = max_concurrency
        __props__.__dict__["memory_mb"] = memory_mb
        __props__.__dict__["metadatas"] = metadatas
        __props__.__dict__["pending"] = pending
        __props__.__dict__["request_timeout"] = request_timeout
        __props__.__dict__["revision_number"] = revision_number
        __props__.__dict__["sandbox_id"] = sandbox_id
        __props__.__dict__["status"] = status
        __props__.__dict__["timeout"] = timeout
        return Sandbox(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例所在可用区 ID。
        """
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter(name="cpuMilli")
    def cpu_milli(self) -> pulumi.Output[builtins.int]:
        """
        沙箱实例 CPU 规格：单位：milli cpu取值范围：250~16000,默认值：1000。
        """
        return pulumi.get(self, "cpu_milli")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def envs(self) -> pulumi.Output[Sequence['outputs.SandboxEnv']]:
        return pulumi.get(self, "envs")

    @property
    @pulumi.getter(name="errorCode")
    def error_code(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例启动失败错误码。参数值说明：internal*load*request*error：系统内部错误，function*initialize*failed：业务进程初始化错误，function*health*check*failed：健康检查错误，route_terminating：路由删除中，正常启动沙箱实例时，该字段为空。
        """
        return pulumi.get(self, "error_code")

    @property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例启动失败的错误码详情。正常启动沙箱实例时，该字段为空。
        """
        return pulumi.get(self, "error_message")

    @property
    @pulumi.getter(name="expireAt")
    def expire_at(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例存活时长。
        """
        return pulumi.get(self, "expire_at")

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例所属的沙箱应用 ID。
        """
        return pulumi.get(self, "function_id")

    @property
    @pulumi.getter(name="instanceImageInfo")
    def instance_image_info(self) -> pulumi.Output['outputs.SandboxInstanceImageInfo']:
        """
        沙箱实例镜像信息，包括镜像地址、启动命令、监听端口。
        """
        return pulumi.get(self, "instance_image_info")

    @property
    @pulumi.getter(name="instanceTosMountConfig")
    def instance_tos_mount_config(self) -> pulumi.Output['outputs.SandboxInstanceTosMountConfig']:
        """
        沙箱实例级别对象存储（TOS）存储挂载配置。
        """
        return pulumi.get(self, "instance_tos_mount_config")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例类型 。参数值说明：elastic：弹性实例，frozen：冻结实例，activated：激活实例，reserved：预留实例。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> pulumi.Output[builtins.int]:
        """
        单实例请求最大并发数：取值范围：10~1000,默认值：100。
        """
        return pulumi.get(self, "max_concurrency")

    @property
    @pulumi.getter(name="memoryMb")
    def memory_mb(self) -> pulumi.Output[builtins.int]:
        """
        沙箱实例内存规格：单位：MiB，取值范围：512~131072，默认值：2048
        """
        return pulumi.get(self, "memory_mb")

    @property
    @pulumi.getter
    def metadatas(self) -> pulumi.Output[Sequence['outputs.SandboxMetadata']]:
        return pulumi.get(self, "metadatas")

    @property
    @pulumi.getter
    def pending(self) -> pulumi.Output[builtins.bool]:
        """
        沙箱实例是否处于 Pending 状态。参数值说明：true：是，false：否。
        """
        return pulumi.get(self, "pending")

    @property
    @pulumi.getter(name="requestTimeout")
    def request_timeout(self) -> pulumi.Output[builtins.int]:
        """
        请求超时时间：单位：秒，取值范围：1~900，正整数。默认值：30。
        """
        return pulumi.get(self, "request_timeout")

    @property
    @pulumi.getter(name="revisionNumber")
    def revision_number(self) -> pulumi.Output[builtins.int]:
        """
        函数实例版本编号。
        """
        return pulumi.get(self, "revision_number")

    @property
    @pulumi.getter(name="sandboxId")
    def sandbox_id(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例 ID。
        """
        return pulumi.get(self, "sandbox_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        沙箱实例状态。 参数值说明：Starting：开始启动，Ready：启动完成，Failed：启动失败，Terminating：终止中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[builtins.int]:
        """
        沙箱实例存活时长：单位：分钟，取值范围：3～1440，默认值：60。
        """
        return pulumi.get(self, "timeout")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .custom_domain import *
from .gateway import *
from .gateway_service import *
from .get_custom_domain import *
from .get_custom_domains import *
from .get_gateway import *
from .get_gateway_service import *
from .get_gateway_services import *
from .get_gateways import *
from .get_upstream import *
from .get_upstream_source import *
from .get_upstream_sources import *
from .get_upstreams import *
from .upstream import *
from .upstream_source import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DnsControlPolicyDomainListV1Args',
    'DnsControlPolicyDomainListV1ArgsDict',
    'DnsControlPolicySourceArgs',
    'DnsControlPolicySourceArgsDict',
]

MYPY = False

if not MYPY:
    class DnsControlPolicyDomainListV1ArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[builtins.str]]
        """
        具体地址信息。
        """
        description: NotRequired[pulumi.Input[builtins.str]]
        """
        描述信息。
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        地址类型。支持的取值如下所示。ip：IPv4 地址；ipv6：IPv6 地址；domain：域名；port：端口。
        """
elif False:
    DnsControlPolicyDomainListV1ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DnsControlPolicyDomainListV1Args:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] address: 具体地址信息。
        :param pulumi.Input[builtins.str] description: 描述信息。
        :param pulumi.Input[builtins.str] type: 地址类型。支持的取值如下所示。ip：IPv4 地址；ipv6：IPv6 地址；domain：域名；port：端口。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        具体地址信息。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        地址类型。支持的取值如下所示。ip：IPv4 地址；ipv6：IPv6 地址；domain：域名；port：端口。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class DnsControlPolicySourceArgsDict(TypedDict):
        region: NotRequired[pulumi.Input[builtins.str]]
        """
        VPC地域信息。
        """
        vpc_id: NotRequired[pulumi.Input[builtins.str]]
        """
        VPC ID。
        """
elif False:
    DnsControlPolicySourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DnsControlPolicySourceArgs:
    def __init__(__self__, *,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] region: VPC地域信息。
        :param pulumi.Input[builtins.str] vpc_id: VPC ID。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC地域信息。
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCustomDomainResult',
    'AwaitableGetCustomDomainResult',
    'get_custom_domain',
    'get_custom_domain_output',
]

@pulumi.output_type
class GetCustomDomainResult:
    """
    A collection of values returned by getCustomDomain.
    """
    def __init__(__self__, certificate_id=None, comments=None, created_time=None, custom_domain_id=None, domain=None, id=None, protocols=None, service_id=None, ssl_redirect=None, status=None, updated_time=None):
        if certificate_id and not isinstance(certificate_id, str):
            raise TypeError("Expected argument 'certificate_id' to be a str")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if comments and not isinstance(comments, str):
            raise TypeError("Expected argument 'comments' to be a str")
        pulumi.set(__self__, "comments", comments)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if custom_domain_id and not isinstance(custom_domain_id, str):
            raise TypeError("Expected argument 'custom_domain_id' to be a str")
        pulumi.set(__self__, "custom_domain_id", custom_domain_id)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if protocols and not isinstance(protocols, list):
            raise TypeError("Expected argument 'protocols' to be a list")
        pulumi.set(__self__, "protocols", protocols)
        if service_id and not isinstance(service_id, str):
            raise TypeError("Expected argument 'service_id' to be a str")
        pulumi.set(__self__, "service_id", service_id)
        if ssl_redirect and not isinstance(ssl_redirect, bool):
            raise TypeError("Expected argument 'ssl_redirect' to be a bool")
        pulumi.set(__self__, "ssl_redirect", ssl_redirect)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> builtins.str:
        """
        自定义域名证书ID。
        """
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter
    def comments(self) -> builtins.str:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customDomainId")
    def custom_domain_id(self) -> builtins.str:
        """
        自定义域名ID。
        """
        return pulumi.get(self, "custom_domain_id")

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        """
        自定义域名。
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def protocols(self) -> Sequence[builtins.str]:
        """
        协议，取值：HTTP。HTTPS。
        """
        return pulumi.get(self, "protocols")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> builtins.str:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="sslRedirect")
    def ssl_redirect(self) -> builtins.bool:
        """
        重定向到HTTPS。
        """
        return pulumi.get(self, "ssl_redirect")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        状态，取值：Creating：配置中。CreationFailed：配置失败。Deleting：删除中。DeletionFailed：删除失败。Verified：正常。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetCustomDomainResult(GetCustomDomainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCustomDomainResult(
            certificate_id=self.certificate_id,
            comments=self.comments,
            created_time=self.created_time,
            custom_domain_id=self.custom_domain_id,
            domain=self.domain,
            id=self.id,
            protocols=self.protocols,
            service_id=self.service_id,
            ssl_redirect=self.ssl_redirect,
            status=self.status,
            updated_time=self.updated_time)


def get_custom_domain(id: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCustomDomainResult:
    """
    Data Source schema for Byteplus::APIG::CustomDomain


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:apig/getCustomDomain:getCustomDomain', __args__, opts=opts, typ=GetCustomDomainResult).value

    return AwaitableGetCustomDomainResult(
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        comments=pulumi.get(__ret__, 'comments'),
        created_time=pulumi.get(__ret__, 'created_time'),
        custom_domain_id=pulumi.get(__ret__, 'custom_domain_id'),
        domain=pulumi.get(__ret__, 'domain'),
        id=pulumi.get(__ret__, 'id'),
        protocols=pulumi.get(__ret__, 'protocols'),
        service_id=pulumi.get(__ret__, 'service_id'),
        ssl_redirect=pulumi.get(__ret__, 'ssl_redirect'),
        status=pulumi.get(__ret__, 'status'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_custom_domain_output(id: Optional[pulumi.Input[builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCustomDomainResult]:
    """
    Data Source schema for Byteplus::APIG::CustomDomain


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:apig/getCustomDomain:getCustomDomain', __args__, opts=opts, typ=GetCustomDomainResult)
    return __ret__.apply(lambda __response__: GetCustomDomainResult(
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        comments=pulumi.get(__response__, 'comments'),
        created_time=pulumi.get(__response__, 'created_time'),
        custom_domain_id=pulumi.get(__response__, 'custom_domain_id'),
        domain=pulumi.get(__response__, 'domain'),
        id=pulumi.get(__response__, 'id'),
        protocols=pulumi.get(__response__, 'protocols'),
        service_id=pulumi.get(__response__, 'service_id'),
        ssl_redirect=pulumi.get(__response__, 'ssl_redirect'),
        status=pulumi.get(__response__, 'status'),
        updated_time=pulumi.get(__response__, 'updated_time')))
